@@ -297,7 +297,7 @@ def run_server(bind_address):
 def get_parser():
     parser = argparse.ArgumentParser(description="Aiges ArgsPare")
     parser.add_argument('-w', dest="workers_nums", default=2, type=int)
-    parser.add_argument('-s', dest="single", default=True, type=bool)
+    parser.add_argument('-c', dest="concurrent", action="store_true")
 
     return parser
 
@@ -310,7 +310,8 @@ def main():
 
     parser = get_parser()
     opts = parser.parse_args()
-    if opts.single:
+    if not opts.concurrent:
+        print("using old...")
         run_old()
     else:
         workers_nums = opts.workers_nums
